@@ -7,15 +7,18 @@
 #' as long as you do not change the filenames of the original GeoJSON files.
 #' @param path
 #'   Path to the ZIP file containing one or more GeoJSON format files.
+#' @param stringsAsFactors
+#'   logical. should character vectors be converted to factors?
 #' @param quiet
 #'   logical. Suppress information about the data to be read.
-#'
 #' @returns A list of [sf::sf()] objects.
+#'
 #' @examples
 #' path <- system.file("extdata", "castle.zip", package = "fude")
-#' d <- read_fude(path)
+#' d <- read_fude(path, stringsAsFactors = FALSE)
+#'
 #' @export
-read_fude <- function(path, quiet = FALSE) {
+read_fude <- function(path, stringsAsFactors = TRUE, quiet = FALSE) {
   if (!grepl(".zip$", path)) {
     stop(path, " is not a ZIP file.")
   }
@@ -32,5 +35,14 @@ read_fude <- function(path, quiet = FALSE) {
   x <- lapply(json_files, sf::st_read, quiet = quiet)
   names(x) <- gsub("^.*/|.json", "", json_files)
 
+  if (stringsAsFactors == TRUE) {
+    x <- purrr::map(x, function(df) {
+      df$land_type <- factor(df$land_type,
+                             levels = c(100, 200),
+                             labels = c("\u7530", "\u7551"))
+      return(df)
+    })
+  }
+
   return(x)
 }
